==> maDB_1.4.0.tar.gz: maDB/man/dbCalculateRegulations.Rd <==
\name{dbCalculateRegulations}
\alias{dbCalculateRegulations}
\title{Calculate regulation values from expression values in the database}
\description{
  \code{dbCalculateRegulations} This function calculates regulation values from expresison values in the database and inserts the newly calculated regulation values in the according database table. 
}
\usage{
dbCalculateRegulations(Con,exp.title,comparisons,v=TRUE)
}
\arguments{
  \item{Con}{The connection to the database (see \code{\link{dbConnect}} from the \pkg{RdbiPgSQL} package).}
  \item{exp.title}{The tile of the micro array experiment for which the regulation values should be calculated. Note that it is only possible to calculate regulation values for comparisons of arrays within a micro array experiment, which means that this regulation values can only be calculated for arrays or Affymetrix GeneChips which were normalized together and their expression values have been adjusted between the arrays.}
  \item{comparisons}{A list of comparisons that should be calculated. To calculate regulation values for the first three chips of an experiment (comparing the expression values of the second chip with those of the first (control) and the same for the third) submit \code{list(c(2,1),c(3,1))}. Use the function \code{\link{dbGetExperimentInfo}} to get the information at which index which sample is stored in the database.}
  \item{v}{If \code{TRUE} a progress bar will be drawn.}
}
\details{
This function allows to calculate regulation values comparing expression values from signal channels of an micro array experiment. The according comparisons will be inserted into a database table called \code{comparisons} whichs attribute \code{r\_signal\_channel} links to the signal channel that was used as sample and whichs attribute \code{g\_signal\_channel} links to the signal channel that was used as control sample. The regulation values are calculated using the formula \code{M=r-g} and \code{A=0.5*(r+g)} where \code{r} and \code{g} are the expression values in log2 scale. The regulation values (M and A values) are inserted into a database table called \code{regulation_values}.
Regulation values can be fetched from the database using the \code{\link{getMDB}} function. To get the information which samples were compared in the comparisons in the database the \dQuote{samples} and \dQuote{comparisons} can be joined (eg \code{dbSendQuery(con,"SELECT * FORM comparisons JOIN signal\_channels ON (r\_signal\_channel=signal\_channels\_pk) JOIN samples ON (samples\_fk=samples\_pk)")} gets all comparisons from the database togehter with the information of which signal channel with which sample hybridized onto was used as \dQuote{red} channel. By switching the \dQuote{red\_signal\_channel} with \dQuote{green\_signal\_channel} the same can be done for the \dQuote{green} signal channel (usually the control sample in the formula \code{M = log2(R/G)})).
}
\references{}
\author{Johannes Rainer}

\seealso{
	\code{\link{dbGetExperimentInfo}}
}


\keyword{data}

==> maDB_1.6.0.tar.gz: maDB/man/dbCalculateRegulations.Rd <==
\name{dbCalculateRegulations}
\alias{dbCalculateRegulations}
\title{Calculate regulation values from expression values in the database}
\description{
  \code{dbCalculateRegulations} This function calculates regulation values from expresison values in the database and inserts the newly calculated regulation values in the according database table. 
}
\usage{
dbCalculateRegulations(Con,exp.title,comparisons,v=TRUE)
}
\arguments{
  \item{Con}{The connection to the database (see \code{dbConnect} from the \pkg{RdbiPgSQL} package).}
  \item{exp.title}{The tile of the micro array experiment for which the regulation values should be calculated. Note that it is only possible to calculate regulation values for comparisons of arrays within a micro array experiment, which means that this regulation values can only be calculated for arrays or Affymetrix GeneChips which were normalized together and their expression values have been adjusted between the arrays.}
  \item{comparisons}{A list of comparisons that should be calculated. To calculate regulation values for the first three chips of an experiment (comparing the expression values of the second chip with those of the first (control) and the same for the third) submit \code{list(c(2,1),c(3,1))}. Use the function \code{\link{dbGetExperimentInfo}} to get the information at which index which sample is stored in the database.}
  \item{v}{If \code{TRUE} a progress bar will be drawn.}
}
\details{
This function allows to calculate regulation values comparing expression values from signal channels of an micro array experiment. The according comparisons will be inserted into a database table called \code{comparisons} whichs attribute \code{r\_signal\_channel} links to the signal channel that was used as sample and whichs attribute \code{g\_signal\_channel} links to the signal channel that was used as control sample. The regulation values are calculated using the formula \code{M=r-g} and \code{A=0.5*(r+g)} where \code{r} and \code{g} are the expression values in log2 scale. The regulation values (M and A values) are inserted into a database table called \code{regulation_values}.
Regulation values can be fetched from the database using the \code{\link{getMDB}} function. To get the information which samples were compared in the comparisons in the database the \dQuote{samples} and \dQuote{comparisons} can be joined (eg \code{dbSendQuery(con,"SELECT * FORM comparisons JOIN signal\_channels ON (r\_signal\_channel=signal\_channels\_pk) JOIN samples ON (samples\_fk=samples\_pk)")} gets all comparisons from the database togehter with the information of which signal channel with which sample hybridized onto was used as \dQuote{red} channel. By switching the \dQuote{red\_signal\_channel} with \dQuote{green\_signal\_channel} the same can be done for the \dQuote{green} signal channel (usually the control sample in the formula \code{M = log2(R/G)})).
}
\references{}
\author{Johannes Rainer}

\seealso{
	\code{\link{dbGetExperimentInfo}}
}


\keyword{data}
